==> agr-center-api-3.1.0-CLOUD-TEST-20231213.075412-1-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrMainDetailBo.java <==
package com.tydic.dyc.agr.service.agr.bo;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigDetailBo;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigDetailBo;
import java.util.Date;
import java.util.List;
import java.math.BigDecimal;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrMainDetailBo implements Serializable {
	private static final long serialVersionUID =  4011647822435370431L;

	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议模式转义
	 */
	private String agrModeStr;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议分类转义
	 */
	private String agrTypeStr;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议状态转义
	 */
	private String agrStatusStr;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议价格类型转义
	 */
	private String agrPriceTypeStr;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源转义
	 */
	private String agrSrcStr;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 交易模式转义
	 */
	private String tradeModeStr;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 铺货方式转义
	 */
	private String vendorModeStr;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否配送转义
	 */
	private String whetherDispatchStr;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 是否分配转义
	 */
	private String whetherAssignStr;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 采购类别转义
	 */
	private String agreementVarietyStr;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 所属专区转义
	 */
	private String agrLocationStr;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否商城铺货标识转义
	 */
	private String whetherStorePlanStr;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 是否是否有明细标识转义
	 */
	private String whetherHaveItemStr;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 应用范围类型转义
	 */
	private String scopeTypeStr;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 调价机制转义
	 */
	private String adjustPriceStr;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 编制人名称
	 */
	private String createName;
	/**
	 * 编制人用户名
	 */
	private String createUsername;
	/**
	 * 编制人ID
	 */
	private Long createLoginId;
	/**
	 * 编制时间
	 */
	private Date createTime;
	/**
	 * 编制人单位
	 */
	private Long createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 付款方式（对供应商）
	 */
	private AgrPayConfigDetailBo payTypeSup;
	/**
	 * 付款方式（对采购商）
	 */
	private AgrPayConfigDetailBo payTypePur;
	/**
	 * 协议主体拓展
	 */
	private List<AgrMainExtBo> agrMainExtBOs;
	/**
	 * 是否存在加价项
	 */
	private Integer whetherAddPrice;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 是否公式调价
	 */
	private Integer whetherAdjustPriceFormula;
	/**
	 * 是否手动修改采购单价
	 */
	private Integer whetherModifyBuyPrice;
	/**
	 * 调价公式ID
	 */
	private Long adjustPriceFormulaId;
	/**
	 * 调价公式名称
	 */
	private String adjustPriceFormulaName;
	/**
	 * 调价公式值
	 */
	private String adjustPriceFormulaValue;
	/**
	 * 调价公式说明
	 */
	private String adjustPriceFormula;
	/**
	 * 排序
	 */
	private String orderBy;
	/**
	 * 服务费比例
	 */
	private String serviceRate;
}

==> agr-center-api-3.2.2-CLOUD-TEST-20240509.015400-2-sources.jar: com/tydic/dyc/agr/service/agr/bo/AgrMainDetailBo.java <==
package com.tydic.dyc.agr.service.agr.bo;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigDetailBo;
import com.tydic.dyc.agr.service.agr.bo.AgrPayConfigDetailBo;
import java.util.Date;
import java.util.List;
import java.math.BigDecimal;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrMainDetailBo implements Serializable {
	private static final long serialVersionUID =  4011647822435370431L;

	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议模式转义
	 */
	private String agrModeStr;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议分类转义
	 */
	private String agrTypeStr;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议状态转义
	 */
	private String agrStatusStr;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议价格类型转义
	 */
	private String agrPriceTypeStr;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源转义
	 */
	private String agrSrcStr;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 交易模式转义
	 */
	private String tradeModeStr;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 铺货方式转义
	 */
	private String vendorModeStr;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否配送转义
	 */
	private String whetherDispatchStr;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 是否分配转义
	 */
	private String whetherAssignStr;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private String managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 采购类别转义
	 */
	private String agreementVarietyStr;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 所属专区转义
	 */
	private String agrLocationStr;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否商城铺货标识转义
	 */
	private String whetherStorePlanStr;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 是否是否有明细标识转义
	 */
	private String whetherHaveItemStr;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 应用范围类型转义
	 */
	private String scopeTypeStr;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 调价机制转义
	 */
	private String adjustPriceStr;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 编制人名称
	 */
	private String createName;
	/**
	 * 编制人用户名
	 */
	private String createUsername;
	/**
	 * 编制人ID
	 */
	private Long createLoginId;
	/**
	 * 编制时间
	 */
	private Date createTime;
	/**
	 * 编制人单位
	 */
	private Long createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 付款方式（对供应商）
	 */
	private AgrPayConfigDetailBo payTypeSup;
	/**
	 * 付款方式（对采购商）
	 */
	private AgrPayConfigDetailBo payTypePur;
	/**
	 * 协议主体拓展
	 */
	private List<AgrMainExtBo> agrMainExtBOs;
	/**
	 * 是否存在加价项
	 */
	private Integer whetherAddPrice;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 是否公式调价
	 */
	private Integer whetherAdjustPriceFormula;
	/**
	 * 是否手动修改采购单价
	 */
	private Integer whetherModifyBuyPrice;
	/**
	 * 调价公式ID
	 */
	private Long adjustPriceFormulaId;
	/**
	 * 调价公式名称
	 */
	private String adjustPriceFormulaName;
	/**
	 * 调价公式值
	 */
	private String adjustPriceFormulaValue;
	/**
	 * 调价公式说明
	 */
	private String adjustPriceFormula;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String agrMainExtend1;
	/**
	 * 扩展字段2
	 */
	private String agrMainExtend2;
	/**
	 * 扩展字段3
	 */
	private String agrMainExtend3;
	/**
	 * 扩展字段4
	 */
	private String agrMainExtend4;
	/**
	 * 扩展字段5
	 */
	private String agrMainExtend5;
	/**
	 * 扩展字段6
	 */
	private String agrMainExtend6;
	/**
	 * 扩展字段7
	 */
	private String agrMainExtend7;
	/**
	 * 扩展字段8
	 */
	private String agrMainExtend8;
	/**
	 * 扩展字段9
	 */
	private String agrMainExtend9;
	/**
	 * 扩展json
	 */
	private String agrMainExtendJson;
	/**
	 * 父协议编号
	 */
	private String parentAgrCode;
	/**
	 * 扩展对象
	 */
	private AgrMainExtendBo agrMainExtendBo;
	/**
	 * 机构树路径
	 */
	private String orgPath;
	/**
	 * 外部关联ID
	 */
	private String relId;
	/**
	 * 外部关联名称
	 */
	private String relName;
	/**
	 * 协议来源ID
	 */
	private String agrSrcId;
	/**
	 * 不含税金额
	 */
	private BigDecimal noTaxAmount;
	/**
	 * 排序
	 */
	private String orderBy;
	/**
	 * 是否代理商
	 */
	private Integer agentFlag;
	/**
	 * 是否代理商转义
	 */
	private String agentFlagStr;
	/**
	 * 原厂商名称
	 */
	private String originalManufacturer;
	/**
	 * 是否代管供应商
	 */
	private Integer escrowVendorFlag;
	/**
	 * 是否代管供应商转义
	 */
	private String escrowVendorFlagStr;
	/**
	 * 合同签订依据
	 */
	private String agrMainExtend10;
	/**
	 * 扩展字段5转义：是否共享限额类：0否 1是
	 */
	private String agrMainExtend5Str;
	/**
	 * 扩展字段9：是否自动续约类：0否 1是
	 */
	private String agrMainExtend9Str;
	/**
	 * 协议创建公司ID
	 */
	private Long createCompanyId;
	/**
	 * 协议创建公司名称
	 */
	private String createCompanyName;
}
